LLM API Key - MindRoot 9.10.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# LLM API Key

For this section you will need an API key from an LLM provider. We will assume OpenRouter for this example.

Now, enter your OpenRouter API key:

- Go to /admin (Admin link on home page) Advanced | Environment Variables

- Find the ah_openrouter section and the OPENROUTER_KEY field; click Edit.

- Enter your key and press Save.

Finally, restart MindRoot:

- Go to Admin | Server Settings | Server Control

- Click on Restart Server